@@ -80,6 +80,11 @@ import prettytable  # pip install PrettyTable
 import semver
 # import texttable  # ... can't deal with Unicode properly
 
+try:
+    import chardet
+except ImportError:
+    chardet = None
+
 try:
     # noinspection PyPackageRequirements
     import docx  # pip install python-docx (NOT docx) - BUT python-docx requires lxml which has C dependencies  # noqa
@@ -222,11 +227,32 @@ def get_file_contents(filename: str = None, blob: bytes = None,
 
 
 def get_file_contents_text(filename: str = None, blob: bytes = None,
-                           encoding = sys.getdefaultencoding(),
+                           encoding = None,
                            **kwargs) -> str:
     """Returns string contents of a file, or blob."""
     binary_contents = get_file_contents(filename=filename, blob=blob, **kwargs)
-    return binary_contents.decode(encoding)
+    # 1. Try the encoding the user specified
+    if encoding:
+        try:
+            return binary_contents.decode(encoding)
+        except ValueError:  # of which UnicodeDecodeError is more specific
+            # ... https://docs.python.org/3/library/codecs.html
+            pass
+    # 2. Try the system encoding
+    sysdef = sys.getdefaultencoding()
+    if sysdef != encoding:
+        try:
+            return binary_contents.decode(sysdef)
+        except ValueError:
+            pass
+    # 3. Try the best guess from chardet
+    #    http://chardet.readthedocs.io/en/latest/usage.html
+    if chardet:
+        guess = chardet.detect(binary_contents)
+        if guess['encoding']:
+            return binary_contents.decode(guess['encoding'])
+    raise ValueError("Unknown encoding ({})".format(
+        "filename={}".format(repr(filename)) if filename else "blob"))
 
 
 def get_cmd_output(*args, **kwargs) -> str:
