@@ -4,7 +4,7 @@
 # See LICENSE for details.
 
 
-VERSION = '0.2.10'
+VERSION = '0.2.11'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -19,4 +19,7 @@ RECENT_VERSION_HISTORY = """
 - 0.2.10, 2017-04-29
   Text fetch (for converters) was returning bytes, not str; fixed.
 
+- 0.2.11, 2017-04-29
+  Encoding auto-detection for text extraction from files.
+
 """
